@@ -1,5 +1,5 @@
 import typing
-from functools import cached_property
+from cached_property import cached_property
 from wsgiref.util import FileWrapper
 
 from miniweb.exceptions import PayloadTooLarge
@@ -10,9 +10,13 @@ from .response import HttpResponse
 from .response import HttpChunkResponseData
 from .router import Router
 
+MiniwebRequestHandlerType = typing.Callable[[HttpRequest, HttpResponse], None] # miniweb defined handler type
+WsgiHandlerResultType = typing.Union[typing.List[bytes], FileWrapper, HttpChunkResponseData] # wsgi defined handler result type
+WsgiEnvType = typing.Any
+WsgiStartResponseType = typing.Any
 
 class Middleware(object):
-    def __init__(self, get_response:typing.Callable[[HttpRequest, HttpResponse], None]) -> None:
+    def __init__(self, get_response:MiniwebRequestHandlerType) -> None:
         self.get_response = get_response
     
     def __call__(self, http_request:HttpRequest, http_response:HttpResponse) -> None:
@@ -20,16 +24,16 @@ class Middleware(object):
 
 class Application(object):
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.middlewares = []
         self.router = Router()
         self.global_permitted_methods = []
 
-    def set_middlewares(self, middlewares:typing.List[Middleware]):
+    def set_middlewares(self, middlewares:typing.List[Middleware]) -> None:
         self.middlewares = [] + middlewares
 
     @cached_property
-    def dispatch_chain(self):
+    def dispatch_chain(self) -> MiniwebRequestHandlerType:
         dispatch = self.dispatch
         for middleware_class in reversed(self.middlewares):
             dispatch = middleware_class(dispatch)
@@ -50,13 +54,13 @@ class Application(object):
                 except PayloadTooLarge as error:
                     http_response.payload_too_large(error.args[0], error.args[1])
 
-    def __call__(self, env, start_response):
+    def __call__(self, env:WsgiEnvType, start_response:WsgiStartResponseType) -> WsgiHandlerResultType:
         http_request = HttpRequest(env, application=self)
         http_response = HttpResponse(start_response, request=http_request, application=self)
         self.dispatch_chain(http_request, http_response)
         return self.do_final_response(http_request, http_response)
 
-    def do_final_response(self, http_request:HttpRequest, http_response:HttpResponse):
+    def do_final_response(self, http_request:HttpRequest, http_response:HttpResponse) -> WsgiHandlerResultType:
         http_response.start_response(http_response.final_status_code, http_response.final_headers)
         final_content = http_response.final_content
         if not final_content:
