@@ -175,18 +175,18 @@ class HttpResponse(object):
     def make_cookie(cls, name:str, value:str, expires:datetime.datetime=None, max_age:int=None, domain:str=None, path:str="/", secure:bool=True, httpOnly:bool=True, sameSite:str=None):
         name = quote(name)
         value = quote(value)
-        cookie_parts = [f"{name}={value}"]
+        cookie_parts = ["{name}={value}".format(name=name, value=value)]
         if expires:
             expires = time.strftime("%a, %d %b %Y %H:%M:%S GMT", time.gmtime(expires.timestamp()))
-            cookie_parts.append(f"Expires={expires}")
+            cookie_parts.append("Expires={expires}".format(expires=expires))
         if max_age:
-            cookie_parts.append(f"Max-Age={max_age}")
+            cookie_parts.append("Max-Age={max_age}".format(max_age=max_age))
         if domain:
-            cookie_parts.append(f"Domain={domain}")
+            cookie_parts.append("Domain={domain}".format(domain=domain))
         if path:
-            cookie_parts.append(f"Path={path}")
+            cookie_parts.append("Path={path}".format(path=path))
         if sameSite:
-            cookie_parts.append(f"SameSite={sameSite}")
+            cookie_parts.append("SameSite={sameSite}".format(sameSite=sameSite))
         if secure:
             cookie_parts.append("Secure")
         if httpOnly:
